changeset 742:ce139fc6e574 draft

Updated.
author Pavel Tisnovsky <ptisnovs@redhat.com>
date Wed, 15 Jul 2015 12:25:10 +0200
parents 8133aa764216
children 1e053216bad2
files ChangeLog src/org/gfxtest/testsuites/BitBltUsingBgColor.java
diffstat 2 files changed, 65 insertions(+), 60 deletions(-) [+]
line wrap: on
line diff
--- a/ChangeLog	Tue Jul 14 11:41:23 2015 +0200
+++ b/ChangeLog	Wed Jul 15 12:25:10 2015 +0200
@@ -1,3 +1,8 @@
+2015-07-15  Pavel Tisnovsky  <ptisnovs@redhat.com>
+
+	* src/org/gfxtest/testsuites/BitBltUsingBgColor.java:
+	Updated.
+
 2015-07-14  Pavel Tisnovsky  <ptisnovs@redhat.com>
 
 	* src/org/gfxtest/testsuites/BitBltUsingBgColor.java:
--- a/src/org/gfxtest/testsuites/BitBltUsingBgColor.java	Tue Jul 14 11:41:23 2015 +0200
+++ b/src/org/gfxtest/testsuites/BitBltUsingBgColor.java	Wed Jul 15 12:25:10 2015 +0200
@@ -11191,7 +11191,7 @@
     }
 
     /**
      * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_BINARY.
      * Background color is set to Color.white.
      *
      * @param image
@@ -11200,13 +11200,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltCheckerBufferedImageTypeByteBinaryBackgroundWhite(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltCheckerBufferedImageTypeByteBinary(image, graphics2d, Color.white);
-    }
-
-    /**
-     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_GRAY.
+    public TestResult testBitBltDiagonalCheckerBufferedImageType4ByteABGR_Pre_backgroundWhite(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltDiagonalCheckerBufferedImageType4ByteABGR_Pre(image, graphics2d, Color.white);
+    }
+
+    /**
+     * Test basic BitBlt operation for diagonal checker buffered image with type {@link BufferedImage#TYPE_INT_BGR}.
      * Background color is set to Color.black.
      *
      * @param image
@@ -11215,13 +11215,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltCheckerBufferedImageTypeByteGrayBackgroundBlack(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltCheckerBufferedImageTypeByteGray(image, graphics2d, Color.black);
-    }
-
-    /**
-     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_GRAY.
+    public TestResult testBitBltDiagonalCheckerBufferedImageTypeIntBGRbackgroundBlack(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltDiagonalCheckerBufferedImageTypeIntBGR(image, graphics2d, Color.black);
+    }
+
+    /**
+     * Test basic BitBlt operation for diagonal checker buffered image with type {@link BufferedImage#TYPE_INT_BGR}.
      * Background color is set to Color.blue.
      *
      * @param image
@@ -11230,13 +11230,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltCheckerBufferedImageTypeByteGrayBackgroundBlue(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltCheckerBufferedImageTypeByteGray(image, graphics2d, Color.blue);
-    }
-
-    /**
-     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_GRAY.
+    public TestResult testBitBltDiagonalCheckerBufferedImageTypeIntBGRbackgroundBlue(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltDiagonalCheckerBufferedImageTypeIntBGR(image, graphics2d, Color.blue);
+    }
+
+    /**
+     * Test basic BitBlt operation for diagonal checker buffered image with type {@link BufferedImage#TYPE_INT_BGR}.
      * Background color is set to Color.green.
      *
      * @param image
@@ -11245,13 +11245,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltCheckerBufferedImageTypeByteGrayBackgroundGreen(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltCheckerBufferedImageTypeByteGray(image, graphics2d, Color.green);
-    }
-
-    /**
-     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_GRAY.
+    public TestResult testBitBltDiagonalCheckerBufferedImageTypeIntBGRbackgroundGreen(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltDiagonalCheckerBufferedImageTypeIntBGR(image, graphics2d, Color.green);
+    }
+
+    /**
+     * Test basic BitBlt operation for diagonal checker buffered image with type {@link BufferedImage#TYPE_INT_BGR}.
      * Background color is set to Color.cyan.
      *
      * @param image
@@ -11260,13 +11260,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltCheckerBufferedImageTypeByteGrayBackgroundCyan(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltCheckerBufferedImageTypeByteGray(image, graphics2d, Color.cyan);
-    }
-
-    /**
-     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_GRAY.
+    public TestResult testBitBltDiagonalCheckerBufferedImageTypeIntBGRbackgroundCyan(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltDiagonalCheckerBufferedImageTypeIntBGR(image, graphics2d, Color.cyan);
+    }
+
+    /**
+     * Test basic BitBlt operation for diagonal checker buffered image with type {@link BufferedImage#TYPE_INT_BGR}.
      * Background color is set to Color.red.
      *
      * @param image
@@ -11275,13 +11275,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltCheckerBufferedImageTypeByteGrayBackgroundRed(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltCheckerBufferedImageTypeByteGray(image, graphics2d, Color.red);
-    }
-
-    /**
-     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_GRAY.
+    public TestResult testBitBltDiagonalCheckerBufferedImageTypeIntBGRbackgroundRed(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltDiagonalCheckerBufferedImageTypeIntBGR(image, graphics2d, Color.red);
+    }
+
+    /**
+     * Test basic BitBlt operation for diagonal checker buffered image with type {@link BufferedImage#TYPE_INT_BGR}.
      * Background color is set to Color.magenta.
      *
      * @param image
@@ -11290,13 +11290,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltCheckerBufferedImageTypeByteGrayBackgroundMagenta(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltCheckerBufferedImageTypeByteGray(image, graphics2d, Color.magenta);
-    }
-
-    /**
-     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_GRAY.
+    public TestResult testBitBltDiagonalCheckerBufferedImageTypeIntBGRbackgroundMagenta(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltDiagonalCheckerBufferedImageTypeIntBGR(image, graphics2d, Color.magenta);
+    }
+
+    /**
+     * Test basic BitBlt operation for diagonal checker buffered image with type {@link BufferedImage#TYPE_INT_BGR}.
      * Background color is set to Color.yellow.
      *
      * @param image
@@ -11305,13 +11305,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltCheckerBufferedImageTypeByteGrayBackgroundYellow(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltCheckerBufferedImageTypeByteGray(image, graphics2d, Color.yellow);
-    }
-
-    /**
-     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_GRAY.
+    public TestResult testBitBltDiagonalCheckerBufferedImageTypeIntBGRbackgroundYellow(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltDiagonalCheckerBufferedImageTypeIntBGR(image, graphics2d, Color.yellow);
+    }
+
+    /**
+     * Test basic BitBlt operation for diagonal checker buffered image with type {@link BufferedImage#TYPE_INT_BGR}.
      * Background color is set to Color.white.
      *
      * @param image
@@ -11320,9 +11320,9 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltCheckerBufferedImageTypeByteGrayBackgroundWhite(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltCheckerBufferedImageTypeByteGray(image, graphics2d, Color.white);
+    public TestResult testBitBltDiagonalCheckerBufferedImageTypeIntBGRbackgroundWhite(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltDiagonalCheckerBufferedImageTypeIntBGR(image, graphics2d, Color.white);
     }
 
     /**
@@ -11191,7 +11191,7 @@
 
     /**
-     * Test basic BitBlt operation for checker buffered image with type TYPE_BYTE_BINARY.
+     * Test basic BitBlt operation for diagonal checker buffered image with type {@link BufferedImage#TYPE_4BYTE_ABGR_Pre}.
      * Background color is set to Color.white.
      *